@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 from django.apps import AppConfig
-from django.core.checks import Tags, register
+from django.core.checks import register
+from django.core.checks import Tags
 
 from corsheaders.checks import check_settings
 
@@ -8,5 +11,5 @@ class CorsHeadersAppConfig(AppConfig):
     name = "corsheaders"
     verbose_name = "django-cors-headers"
 
-    def ready(self):
+    def ready(self) -> None:
         register(Tags.security)(check_settings)
