@@ -1,11 +1,18 @@
 from __future__ import annotations
 
-from typing import List, Pattern, Sequence, Tuple, Union, cast
+from typing import cast
+from typing import List
+from typing import Pattern
+from typing import Sequence
+from typing import Tuple
+from typing import Union
 
 from django.conf import settings
 
+from corsheaders.defaults import default_headers
+from corsheaders.defaults import default_methods
+
 # Kept here for backwards compatibility
-from corsheaders.defaults import default_headers, default_methods
 
 
 class Settings:
