@@ -2,9 +2,11 @@ from __future__ import annotations
 
 import re
 from typing import Any
-from urllib.parse import ParseResult, urlparse
+from urllib.parse import SplitResult
+from urllib.parse import urlsplit
 
-from django.http import HttpRequest, HttpResponse
+from django.http import HttpRequest
+from django.http import HttpResponse
 from django.utils.cache import patch_vary_headers
 from django.utils.deprecation import MiddlewareMixin
 
@@ -60,8 +62,7 @@ class CorsMiddleware(MiddlewareMixin):
             and origin
             and "ORIGINAL_HTTP_REFERER" not in request.META
         ):
-
-            url = urlparse(origin)
+            url = urlsplit(origin)
             if (
                 not conf.CORS_ALLOW_ALL_ORIGINS
                 and not self.origin_found_in_white_lists(origin, url)
@@ -86,8 +87,8 @@ class CorsMiddleware(MiddlewareMixin):
         view/exception middleware along with the requested view;
         it will call any response middlewares
         """
-        request._cors_enabled = self.is_enabled(request)
-        if request._cors_enabled:
+        request._cors_enabled = self.is_enabled(request)  # type: ignore [attr-defined]
+        if request._cors_enabled:  # type: ignore [attr-defined]
             if conf.CORS_REPLACE_HTTPS_REFERER:
                 self._https_referer_replace(request)
 
@@ -110,7 +111,10 @@ class CorsMiddleware(MiddlewareMixin):
         """
         Do the referer replacement here as well
         """
-        if request._cors_enabled and conf.CORS_REPLACE_HTTPS_REFERER:
+        if (
+            request._cors_enabled  # type: ignore [attr-defined]
+            and conf.CORS_REPLACE_HTTPS_REFERER
+        ):
             self._https_referer_replace(request)
         return None
 
@@ -127,14 +131,14 @@ class CorsMiddleware(MiddlewareMixin):
         if not enabled:
             return response
 
-        patch_vary_headers(response, ["Origin"])
+        patch_vary_headers(response, ("Origin",))
 
         origin = request.META.get("HTTP_ORIGIN")
         if not origin:
             return response
 
         try:
-            url = urlparse(origin)
+            url = urlsplit(origin)
         except ValueError:
             return response
 
@@ -166,7 +170,7 @@ class CorsMiddleware(MiddlewareMixin):
 
         return response
 
-    def origin_found_in_white_lists(self, origin: str, url: ParseResult) -> bool:
+    def origin_found_in_white_lists(self, origin: str, url: SplitResult) -> bool:
         return (
             (origin == "null" and origin in conf.CORS_ALLOWED_ORIGINS)
             or self._url_in_whitelist(url)
@@ -188,8 +192,8 @@ class CorsMiddleware(MiddlewareMixin):
         signal_responses = check_request_enabled.send(sender=None, request=request)
         return any(return_value for function, return_value in signal_responses)
 
-    def _url_in_whitelist(self, url: ParseResult) -> bool:
-        origins = [urlparse(o) for o in conf.CORS_ALLOWED_ORIGINS]
+    def _url_in_whitelist(self, url: SplitResult) -> bool:
+        origins = [urlsplit(o) for o in conf.CORS_ALLOWED_ORIGINS]
         return any(
             origin.scheme == url.scheme and origin.netloc == url.netloc
             for origin in origins
