@@ -5,19 +5,15 @@ from django.test import TestCase
 from django.test.utils import override_settings
 from django.utils.deprecation import MiddlewareMixin
 
-from corsheaders.middleware import (
-    ACCESS_CONTROL_ALLOW_CREDENTIALS,
-    ACCESS_CONTROL_ALLOW_HEADERS,
-    ACCESS_CONTROL_ALLOW_METHODS,
-    ACCESS_CONTROL_ALLOW_ORIGIN,
-    ACCESS_CONTROL_EXPOSE_HEADERS,
-    ACCESS_CONTROL_MAX_AGE,
-)
-from tests.utils import (
-    append_middleware,
-    prepend_middleware,
-    temporary_check_request_hander,
-)
+from corsheaders.middleware import ACCESS_CONTROL_ALLOW_CREDENTIALS
+from corsheaders.middleware import ACCESS_CONTROL_ALLOW_HEADERS
+from corsheaders.middleware import ACCESS_CONTROL_ALLOW_METHODS
+from corsheaders.middleware import ACCESS_CONTROL_ALLOW_ORIGIN
+from corsheaders.middleware import ACCESS_CONTROL_EXPOSE_HEADERS
+from corsheaders.middleware import ACCESS_CONTROL_MAX_AGE
+from tests.utils import append_middleware
+from tests.utils import prepend_middleware
+from tests.utils import temporary_check_request_hander
 
 
 class ShortCircuitMiddleware(MiddlewareMixin):
@@ -322,8 +318,8 @@ class CorsMiddlewareTests(TestCase):
         """
         resp = self.client.get("/", HTTP_ORIGIN="http://example.com")
         request = resp.wsgi_request
-        assert isinstance(request._cors_enabled, bool)
-        assert request._cors_enabled
+        assert isinstance(request._cors_enabled, bool)  # type: ignore [attr-defined]
+        assert request._cors_enabled  # type: ignore [attr-defined]
 
     @override_settings(CORS_ALLOWED_ORIGINS=["http://example.com"])
     def test_works_if_view_deletes_cors_enabled(self):
