@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from django.http import Http404, HttpResponse
+from django.http import Http404
+from django.http import HttpResponse
 from django.urls import path
 
 
